@@ -91,7 +91,8 @@ class MomoPayProcessor:
 
     def getPaymentPayload(self):
         key = random.randint(1000, 9999)
-        secret = hashlib.md5((self.merchant_username+str(key)+self.merchant_password).encode("utf-8")).hexdigest()
+        hash_merchant_password = hashlib.md5(self.merchant_password).encode("utf-8")).hexdigest()
+        secret = hashlib.md5((self.merchant_username+str(key)+hash_merchant_password).encode("utf-8")).hexdigest()
         self.payload = {
             'merchant_id': self.merchantID,
             'secrete': secret,
@@ -114,16 +115,19 @@ class MomoPayProcessor:
         
             if self.callback["Status"] == "PAID":
                 self.status_type = StatusTypes.COMPLETED
+                status = True
             else:
                 self.status_type = StatusTypes.FAILED
+                status = False
 
             try:
                 self.momotrans = MomoTransaction.objects.get(
                     order_id=self.callback["Order_id"],
-                    ext_id=self.callback["InvoiceNo"])
+                    ext_id=self.callback["InvoiceNo"],
+                    status=StatusTypes.PENDING)
                 self.momotrans.final_callback = json.dumps(self.callback , cls=DjangoJSONEncoder)
                 self.momotrans.status = self.status_type                
                 self.momotrans.save()
-                return {"status":True, "transactionID":self.momotrans.id, "amount":self.momotrans.amount}
+                return {"status":status, "transactionID":self.momotrans.id, "amount":self.momotrans.amount}
             except Exception as e:
                 return {"status":False, "message":f"{e}"}
\ No newline at end of file
